eels Package
============

:mod:`base_gos` Module
----------------------

.. automodule:: hyperspy.misc.eels.base_gos
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`effective_angle` Module
-----------------------------

.. automodule:: hyperspy.misc.eels.effective_angle
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`elements` Module
----------------------

.. automodule:: hyperspy.misc.eels.elements
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`hartree_slater_gos` Module
--------------------------------

.. automodule:: hyperspy.misc.eels.hartree_slater_gos
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`hydrogenic_gos` Module
----------------------------

.. automodule:: hyperspy.misc.eels.hydrogenic_gos
    :members:
    :undoc-members:
    :show-inheritance:

